@@ -1,8 +1,8 @@
 """
 :Author: dongyu
 :Date: 2020-04-11 18:44:08
-:LastEditTime: 2020-12-09 15:46:02
-:LastEditors: ChenXiaolei
+:LastEditTime: 2021-01-12 08:35:36
+:LastEditors: HuangJingCan
 :Description: 菜单相关类
 """
 from seven_studio.handlers.studio_base import *
@@ -255,7 +255,7 @@ class DeleteMenuHandler(StudioBaseHandler):
         if menu_id == "":
             return self.reponse_common("MenuIDEmpty", "菜单ID为空")
 
-        MenuInfoModel(self.get_manage_context_key()).del_entity("MenuID=%s", menu_id)
+        MenuInfoModelEx(self.get_manage_context_key()).delete(menu_id)
 
         self.reponse_json_success()
 
