@@ -1,8 +1,8 @@
 """
 :Author: wang kui
 :Date: 2020-03-24 16:32:52
-:LastEditTime: 2020-12-14 11:30:43
-:LastEditors: ChenXiaolei
+:LastEditTime: 2021-01-12 08:36:35
+:LastEditors: HuangJingCan
 :Description: power 用户权限相关接口
 """
 from seven_studio.handlers.studio_base import *
@@ -62,42 +62,29 @@ class GetUserProductListHandler(StudioBaseHandler):
         product_user_model = ProductUserModel(base_manage_context_key)
         product_data = []
         product_infos = []
-        home_info = {
-            "Title": "平台管理",
-            "ImageUrl": "",
-            "ManageUrl": "",
-            "WebUrl": "",
-            "ProductID": 0
-        }
+        home_info = {"Title": "平台管理", "ImageUrl": "", "ManageUrl": "", "WebUrl": "", "ProductID": 0}
         is_super = self.get_is_super()
 
         if is_super:
             product_infos = product_info_model.get_list("IsRelease=1")
             if product_id > 0:
-                if self.__has_home_platform_power(
-                        self.get_curr_user_info()).ResultCode == "0":
+                if self.__has_home_platform_power(self.get_curr_user_info()).ResultCode == "0":
                     product_data.append(home_info)
         else:
-            if self.__has_home_platform_power(
-                    self.get_curr_user_info()).ResultCode == "0":
+            if self.__has_home_platform_power(self.get_curr_user_info()).ResultCode == "0":
                 product_data.append(home_info)
 
-            product_user_list = product_user_model.get_list("UserID=%s",
-                                                            params=user_id)
+            product_user_list = product_user_model.get_list("UserID=%s", params=user_id)
 
             if product_user_list:
-                list_str = str([
-                    i.ProductID for i in product_user_list
-                    if i.ProductID > 0 or product_id == 0
-                ]).strip('[').strip(']')
+                list_str = str([i.ProductID for i in product_user_list if i.ProductID > 0 or product_id == 0]).strip('[').strip(']')
                 condition = f"IsRelease=1 AND ProductID IN({list_str})"
                 product_infos = product_info_model.get_list(condition)
             elif not product_data:
                 return self.reponse_common("NoData", "没有其他平台权限")
 
         for product_info in product_infos:
-            product_data.append(
-                self.__to_user_product_data(user_id, product_info, is_super))
+            product_data.append(self.__to_user_product_data(user_id, product_info, is_super))
 
         self.reponse_json_success(product_data)
 
@@ -114,21 +101,11 @@ class GetUserProductListHandler(StudioBaseHandler):
             has_user_manage = True
             has_role_manage = True
         else:
-            role_user_list = RoleUserModel(
-                product_info.ManageContextKey).get_list("UserID=%s",
-                                                        params=user_id)
-            role_power_list = RolePowerModelEx(
-                product_info.ManageContextKey).get_role_power_list(
-                    [i.RoleID for i in role_user_list])
-            if [
-                    i for i in role_power_list
-                    if i.MenuID == config.get_value("menu_id_user")
-            ]:
+            role_user_list = RoleUserModel(product_info.ManageContextKey).get_list("UserID=%s", params=user_id)
+            role_power_list = RolePowerModelEx(product_info.ManageContextKey).get_role_power_list([i.RoleID for i in role_user_list])
+            if [i for i in role_power_list if i.MenuID == config.get_value("menu_id_user")]:
                 has_user_manage = True
-            if [
-                    i for i in role_power_list
-                    if i.MenuID == config.get_value("menu_id_role")
-            ]:
+            if [i for i in role_power_list if i.MenuID == config.get_value("menu_id_role")]:
                 has_role_manage = True
 
         result_dict = {}
@@ -161,16 +138,11 @@ class GetUserProductListHandler(StudioBaseHandler):
             return invoke_result
         if base_user_info.IsSuper == 1:
             return InvokeResult()
-        role_user_list = RoleUserModel(context_key).get_list(
-            "UserID=%s", params=self.request_user_id())
+        role_user_list = RoleUserModel(context_key).get_list("UserID=%s", params=self.request_user_id())
         if not role_user_list:
             return invoke_result
-        role_power_list = RolePowerModelEx(context_key).get_role_power_list(
-            [i.RoleID for i in role_user_list])
-        role_power_info = [
-            i for i in role_power_list
-            if i.MenuID == config.get_value("menu_id_platform")
-        ]
+        role_power_list = RolePowerModelEx(context_key).get_role_power_list([i.RoleID for i in role_user_list])
+        role_power_info = [i for i in role_power_list if i.MenuID == config.get_value("menu_id_platform")]
         if not role_power_info:
             return invoke_result
 
@@ -190,8 +162,7 @@ class FocusPasswordHandler(StudioBaseHandler):
         :last_editors: HuangJingCan
         """
         invoke_result = InvokeResult()
-        is_force_password = UserInfoModelEx().is_force_password(
-            self.get_curr_user_info())
+        is_force_password = UserInfoModelEx().is_force_password(self.get_curr_user_info())
         if not is_force_password:
             invoke_result.ResultCode = "Has Change Password"
             invoke_result.ResultMessage = "密码已修改过"
@@ -213,8 +184,7 @@ class FocusChangeUserPwHandler(StudioBaseHandler):
         """
         invoke_result = InvokeResult()
         password = self.get_param("password")
-        user_info_model_ex = UserInfoModel(
-            config.get_value("base_manage_context_key"))
+        user_info_model_ex = UserInfoModel(config.get_value("base_manage_context_key"))
         user_info_ex = UserInfoModelEx()
         base_user_info = self.get_base_user_info()
         user_id = ""
@@ -225,8 +195,7 @@ class FocusChangeUserPwHandler(StudioBaseHandler):
         if not is_force_password:
             return self.reponse_common("Error", "无需强制更改密码")
         sign_password = user_info_ex.sign_password(password, user_id)
-        user_info_model_ex.update_table(f"Password=%s", "UserID=%s",
-                                        [sign_password, user_id])
+        user_info_model_ex.update_table(f"Password=%s", "UserID=%s", [sign_password, user_id])
 
         self.logout(user_id)
 
@@ -248,19 +217,16 @@ class ChangeCurrUserPwHandler(StudioBaseHandler):
         invoke_result = InvokeResult()
         password = self.get_param("Password")
         new_password = self.get_param("NewPassword")
-        user_info_model_ex = UserInfoModelEx(
-            config.get_value("base_manage_context_key"))
+        user_info_model_ex = UserInfoModelEx(config.get_value("base_manage_context_key"))
         base_user_info = self.get_base_user_info()
         user_id = ""
         if base_user_info:
             user_id = base_user_info.UserID
 
-        if not user_info_model_ex.verify_password(
-                password, base_user_info.Password, user_id):
+        if not user_info_model_ex.verify_password(password, base_user_info.Password, user_id):
             return self.reponse_common("ErrorPassword", "旧密码错误，请重新输入")
         sign_password = user_info_model_ex.sign_password(new_password, user_id)
-        user_info_model_ex.update_table(f"Password=%s", "UserID=%s",
-                                        [sign_password, user_id])
+        user_info_model_ex.update_table(f"Password=%s", "UserID=%s", [sign_password, user_id])
 
         self.logout(user_id)
 
@@ -287,8 +253,7 @@ class GetRoleListHandler(StudioBaseHandler):
         if not is_super:
             condition = f"ChiefUserID='{user_id}'"
 
-        role_dict_list = RoleInfoModel(manage_context_key).get_dict_list(
-            condition, field="RoleID,RoleName")
+        role_dict_list = RoleInfoModel(manage_context_key).get_dict_list(condition, field="RoleID,RoleName")
 
         self.reponse_json_success(role_dict_list)
 
@@ -322,43 +287,27 @@ class GetRoleUserListHandler(StudioBaseHandler):
                 condition += " AND "
             condition += f"ChiefUserID='{user_id}'"
 
-        page_list, total = role_info_model.get_page_list(
-            "*", page_index, page_size, condition, "", order)
+        page_list, total = role_info_model.get_page_list("*", page_index, page_size, condition, "", order)
         if not page_list:
             return self.reponse_json_success(page_data)
 
         user_ids_list = [i.ModifyUserID for i in page_list]
         user_ids_str = str(user_ids_list).strip('[').strip(']')
-        user_info_list = UserInfoModel(manage_context_key).get_list(
-            f"UserID IN({user_ids_str})")
+        user_info_list = UserInfoModel(manage_context_key).get_list(f"UserID IN({user_ids_str})")
 
         role_ids_list = [i.RoleID for i in page_list]
         role_ids_str = str(role_ids_list).strip('[').strip(']')
-        role_info_list = RoleUserModel(manage_context_key).get_list(
-            f"RoleID IN({role_ids_str})")
+        role_info_list = RoleUserModel(manage_context_key).get_list(f"RoleID IN({role_ids_str})")
 
-        role_power_list = RolePowerModel(manage_context_key).get_list(
-            f"RoleID IN({role_ids_str})")
-        role_power_list = RolePowerEx().get_list_by_role_power_list(
-            role_power_list)
+        role_power_list = RolePowerModel(manage_context_key).get_list(f"RoleID IN({role_ids_str})")
+        role_power_list = RolePowerEx().get_list_by_role_power_list(role_power_list)
 
         for curr_role_info in page_list:
-            curr_role_user_dto = DictUtil.auto_mapper(RoleUserDto(),
-                                                      curr_role_info.__dict__)
-            curr_user_info = [
-                i for i in user_info_list if curr_role_info.ModifyUserID != ""
-                and i.UserID == curr_role_info.ModifyUserID
-            ]
-            curr_role_user_dto.ModifyUser = curr_user_info[
-                0].UserName if curr_user_info else ""
-            curr_role_user_dto.RoleUserIds = [
-                i.UserID for i in role_info_list
-                if i.RoleID == curr_role_info.RoleID
-            ]
-            curr_role_user_dto.RoleMenuIds = [
-                i.MenuCoteID for i in role_power_list
-                if i.RoleID == curr_role_info.RoleID
-            ]
+            curr_role_user_dto = DictUtil.auto_mapper(RoleUserDto(), curr_role_info.__dict__)
+            curr_user_info = [i for i in user_info_list if curr_role_info.ModifyUserID != "" and i.UserID == curr_role_info.ModifyUserID]
+            curr_role_user_dto.ModifyUser = curr_user_info[0].UserName if curr_user_info else ""
+            curr_role_user_dto.RoleUserIds = [i.UserID for i in role_info_list if i.RoleID == curr_role_info.RoleID]
+            curr_role_user_dto.RoleMenuIds = [i.MenuCoteID for i in role_power_list if i.RoleID == curr_role_info.RoleID]
             if curr_role_info.ModifyDate == "1900-01-01 00:00:00":
                 curr_role_user_dto.ModifyDate = ""
             role_user_dto_list.append(curr_role_user_dto.__dict__)
@@ -400,45 +349,29 @@ class GetUserRoleListHandler(StudioBaseHandler):
                 condition += " AND "
             condition += f"ChiefUserID='{user_id}'"
 
-        page_list, total = user_info_model.get_page_list(
-            "*", page_index, page_size, condition, "", order)
+        page_list, total = user_info_model.get_page_list("*", page_index, page_size, condition, "", order)
         if not page_list:
             return self.reponse_json_success(page_data)
 
         chief_user_ids_list = [i.ChiefUserID for i in page_list]
         chief_user_ids_str = str(chief_user_ids_list).strip('[').strip(']')
-        chief_user_info_list = user_info_model.get_list(
-            f"UserID IN({chief_user_ids_str})")
+        chief_user_info_list = user_info_model.get_list(f"UserID IN({chief_user_ids_str})")
 
         user_ids_list = [i.UserID for i in page_list]
         user_ids_str = str(user_ids_list).strip('[').strip(']')
-        role_user_list = RoleUserModel(manage_context_key).get_list(
-            f"UserID IN({user_ids_str})")
+        role_user_list = RoleUserModel(manage_context_key).get_list(f"UserID IN({user_ids_str})")
 
         product_user_list = []
         if product_id == 0:
-            product_user_list = ProductUserModel(
-                config.get_value("base_manage_context_key")).get_list(
-                    f"UserID IN({user_ids_str})")
+            product_user_list = ProductUserModel(config.get_value("base_manage_context_key")).get_list(f"UserID IN({user_ids_str})")
 
         for curr_user_info in page_list:
-            curr_user_role_dto = DictUtil.auto_mapper(UserRoleDto(),
-                                                      curr_user_info.__dict__)
-            curr_user_role_dto.UserRoleIds = [
-                i.RoleID for i in role_user_list
-                if i.UserID == curr_user_info.UserID
-            ]
+            curr_user_role_dto = DictUtil.auto_mapper(UserRoleDto(), curr_user_info.__dict__)
+            curr_user_role_dto.UserRoleIds = [i.RoleID for i in role_user_list if i.UserID == curr_user_info.UserID]
             if product_id == 0:
-                curr_user_role_dto.UserProductIds = [
-                    i.ProductID for i in product_user_list
-                    if i.UserID == curr_user_info.UserID
-                ]
-            chief_user_info = [
-                i for i in chief_user_info_list if curr_user_info.ChiefUserID
-                and i.UserID == curr_user_info.ChiefUserID
-            ]
-            curr_user_role_dto.ChiefUserName = chief_user_info[
-                0].UserName if chief_user_info else ""
+                curr_user_role_dto.UserProductIds = [i.ProductID for i in product_user_list if i.UserID == curr_user_info.UserID]
+            chief_user_info = [i for i in chief_user_info_list if curr_user_info.ChiefUserID and i.UserID == curr_user_info.ChiefUserID]
+            curr_user_role_dto.ChiefUserName = chief_user_info[0].UserName if chief_user_info else ""
             if curr_user_role_dto.LoginDate == "1900-01-01 00:00:00":
                 curr_user_role_dto.LoginDate = ""
             user_role_dto_list.append(curr_user_role_dto.__dict__)
@@ -492,13 +425,11 @@ class SaveUserHandler(StudioBaseHandler):
             user_info = user_info_model.get_entity_by_id(user_id)
             if not user_info:
                 return self.reponse_common("NoExit", "用户不存在")
-            user_info_c = user_info_model.get_entity(
-                "Account=%s AND UserID!=%s", params=[account, user_id])
+            user_info_c = user_info_model.get_entity("Account=%s AND UserID!=%s", params=[account, user_id])
             if user_info_c:
                 return self.reponse_common("Exit", "账号已存在")
         else:
-            user_info_c = user_info_model.get_entity("Account=%s",
-                                                     params=account)
+            user_info_c = user_info_model.get_entity("Account=%s", params=account)
             if user_info_c:
                 return self.reponse_common("Exit", "账号已存在")
 
@@ -512,12 +443,9 @@ class SaveUserHandler(StudioBaseHandler):
         if not self.get_is_super():
             user_info.ChiefUserID = self.request_user_id()
 
-        power_model = PowerModel(manage_context_key, is_super, curr_user_id,
-                                 product_id)
+        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
         is_add = user_id == ""
-        result = power_model.set_user(user_info, user_role_id_str.split(","),
-                                      user_product_id_str.split(","), password,
-                                      change_pw, is_add)
+        result = power_model.set_user(user_info, user_role_id_str.split(","), user_product_id_str.split(","), password, change_pw, is_add)
 
         self.reponse_json_success(result)
 
@@ -553,11 +481,7 @@ class SaveCurrUserHandler(StudioBaseHandler):
         user_info.Avatar = avatar
         user_info.PersonalitySignature = personality_signature
 
-        user_info_model.update_entity(user_info,
-                                      field_list=[
-                                          "Email", "NickName", "Phone",
-                                          "Avatar", "PersonalitySignature"
-                                      ])
+        user_info_model.update_entity(user_info, field_list=["Email", "NickName", "Phone", "Avatar", "PersonalitySignature"])
 
         self.reponse_json_success(user_info)
 
@@ -582,8 +506,7 @@ class GetUserListHandler(StudioBaseHandler):
         if not is_super:
             condition = f"ChiefUserID='{user_id}'"
 
-        user_dict_list = UserInfoModel(manage_context_key).get_dict_list(
-            condition, field="UserID,Account,UserName")
+        user_dict_list = UserInfoModel(manage_context_key).get_dict_list(condition, field="UserID,Account,UserName")
 
         self.reponse_json_success(user_dict_list)
 
@@ -623,13 +546,11 @@ class SaveRoleHandler(StudioBaseHandler):
             role_info = role_info_model.get_entity_by_id(role_id)
             if not role_info:
                 return self.reponse_common("NoExit", "角色不存在")
-            role_info_c = role_info_model.get_entity(
-                "RoleName=%s and RoleID!=%s", params=[role_name, role_id])
+            role_info_c = role_info_model.get_entity("RoleName=%s and RoleID!=%s", params=[role_name, role_id])
             if role_info_c:
                 return self.reponse_common("NoExit", "角色名已存在")
         else:
-            role_info_c = role_info_model.get_entity("RoleName=%s",
-                                                     params=role_name)
+            role_info_c = role_info_model.get_entity("RoleName=%s", params=role_name)
             if role_info_c:
                 return self.reponse_common("NoExit", "角色名已存在")
             role_info.RoleID = UUIDHelper.get_uuid()
@@ -643,11 +564,9 @@ class SaveRoleHandler(StudioBaseHandler):
         role_info.ModifyDate = TimeHelper.get_now_format_time()
         role_info.ModifyUserID = self.request_user_id()
 
-        power_model = PowerModel(manage_context_key, is_super, curr_user_id,
-                                 product_id)
+        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
         is_add = role_id == ""
-        result = power_model.set_role(role_info, role_user_id_str.split(","),
-                                      role_menu_id_str.split(","), is_add)
+        result = power_model.set_role(role_info, role_user_id_str.split(","), role_menu_id_str.split(","), is_add)
         result.ModifyUser = self.get_curr_user_info().UserName
         self.reponse_json_success(result.__dict__)
 
@@ -677,8 +596,7 @@ class RemoveRoleUserHandler(StudioBaseHandler):
         if user_id == "":
             return self.reponse_common("EmptyUserID", "用户ID为空")
 
-        power_model = PowerModel(manage_context_key, is_super, curr_user_id,
-                                 product_id)
+        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
         power_model.remove_role_user(role_id, user_id)
 
         self.reponse_json_success()
@@ -738,8 +656,7 @@ class DeleteUserHandler(StudioBaseHandler):
         if user_id == self.request_user_id():
             return self.reponse_common("RemoveLimit", "当前账号不能删除")
 
-        power_model = PowerModel(manage_context_key, is_super, curr_user_id,
-                                 product_id)
+        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
         power_model.remove_user(curr_user_id, user_id)
 
         self.logout(user_id)
@@ -782,8 +699,7 @@ class ModifyUserStatusHandler(StudioBaseHandler):
         if not is_super and user_info.ChiefUserID != curr_user_id:
             return self.reponse_common("NoExit", "用户不存在")
 
-        user_info_model.update_table("IsLock=%s", "UserID=%s",
-                                     [is_lock, user_id])
+        user_info_model.update_table("IsLock=%s", "UserID=%s", [is_lock, user_id])
 
         self.reponse_json_success()
 
@@ -808,8 +724,7 @@ class ResetUserPasswordHandler(StudioBaseHandler):
         base_manage_context_key = config.get_value("base_manage_context_key")
 
         user_info_model = UserInfoModel(base_manage_context_key)
-        user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(
-            user_id)
+        user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(user_id)
         if not user_info:
             return self.reponse_common("NoExit", "用户不存在")
 
@@ -818,8 +733,7 @@ class ResetUserPasswordHandler(StudioBaseHandler):
 
         sign_password = UserInfoModelEx().sign_password("", user_id)
 
-        user_info_model.update_table("FaildLoginCount=0,Password=%s",
-                                     "UserID=%s", [sign_password, user_id])
+        user_info_model.update_table("FaildLoginCount=0,Password=%s", "UserID=%s", [sign_password, user_id])
 
         self.logout(user_id)
 
@@ -846,16 +760,14 @@ class ResetUserFaildLoginCountHandler(StudioBaseHandler):
         base_manage_context_key = config.get_value("base_manage_context_key")
 
         user_info_model = UserInfoModel(base_manage_context_key)
-        user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(
-            user_id)
+        user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(user_id)
         if not user_info:
             return self.reponse_common("NoExit", "用户不存在")
 
         if not is_super and user_info.ChiefUserID != curr_user_id:
             return self.reponse_common("NoExit", "用户不存在")
 
-        user_info_model.update_table("FaildLoginCount=0", "UserID=%s",
-                                     [user_id])
+        user_info_model.update_table("FaildLoginCount=0", "UserID=%s", [user_id])
 
         self.reponse_json_success()
 
@@ -912,8 +824,7 @@ class CopyUserRoleHandler(StudioBaseHandler):
         is_super = self.get_is_super()
         manage_context_key = self.get_manage_context_key()
 
-        power_model = PowerModel(manage_context_key, is_super, curr_user_id,
-                                 product_id)
+        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
         power_model.copy_user_role(copy_user_id, user_id)
 
-        self.reponse_json_success()
+        self.reponse_json_success()
\ No newline at end of file
